@@ -27,7 +27,8 @@ LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file.
 translation_copyrights="English, German: George Ruinelli\n"+\
                                      (u'Français')+": Fred Kwame Ayanful & Guy Roussin\n"+\
                                      "Dutch: Fred Kwame Ayanful\n"+\
-                                     "Chinese: "+(u'蒋岚')+" (Peter3316)"
+                                     "Chinese: "+(u'蒋岚')+" (Peter3316)\n"+\
+                                     "Czech: "+(u'Vít Stanisalv')
 
 #DEFAULT VALUES
 Yscale_Movement_default=20  #Y stretching of yellow movement bars
